<!--设备领用操作界面-->
<script setup lang="ts">
import TitlePanel from "@/views/ecg/doctor/components/TitlePanel.vue";
import QueuePanel from "@/views/ecg/doctor/components/QueuePanel.vue";
import {DoctorApi, PatientStatisticVO, RoomBedVO} from '@/api/ecg/doctor';
import {QueueVO} from "@/api/ecg/queue";
import {ElNotification} from "element-plus";
import DevReadyPanel from "@/views/ecg/doctor/components/DevReadyPanel.vue";
import {useRoomStore} from "@/store/modules/room";

const roomStore = useRoomStore();

const roomBedVO: RoomBedVO = {
    roomId: null,
    roomName: null,
    bedNo: null,
    checkTypes: null,
    opType: null
}

const onStagePatient = ref<QueueVO>({
  bedNo: "", bookCheckType: 0, bookTimeslot: 0, expired: 0, id: 0, jumpFlag: 0, passed: 0,
  patGender: 0, patId: "", patName: "", roomId: 0, roomName: "", seqNum: 0, status: 0
})

const patientStat = ref<PatientStatisticVO>({
    finishedNum: 0,
    readyNum: 0,
    passedNum: 0,
    queuingNum: 0
})

const autoCall = ref<boolean>(false);
const state = ref<boolean>()

const patientList = ref<QueueVO[]>([])

let timerRunFlag : boolean = false
const bedControlFlag = ref<boolean>(true);
const finishFlag = ref<boolean>(true);
const passFlag = ref<boolean>(true);

const finishNextPatient = async () => {
  finishFlag.value = true
  try {
    patientList.value = await DoctorApi.finishReceiveNextPatient(roomBedVO)
    patientStat.value = await DoctorApi.getDevReadyStatistic(roomBedVO)
    getOnstagePatient()

    // 用于解决 左侧重置后 获取当前 【就诊中】患者
    setOnStagePatient(onStagePatient.value)
  } finally {
    finishFlag.value = false
  }
}

const passNextPatient = async () => {
  passFlag.value = true
  try {
    patientList.value = await DoctorApi.passNextPatient(roomBedVO)
    patientStat.value = await DoctorApi.getDevReadyStatistic(roomBedVO)
    getOnstagePatient()
  } finally {
    passFlag.value = false
  }
}

const callAgain = async () => {
  await DoctorApi.callPatientAgain(roomBedVO)
}

const getOnstagePatient = () => {
  const tempPatient : QueueVO | undefined = patientList.value.find(item => item.status === 30)
  if (undefined === tempPatient) {
    // setOnStagePatient(undefined)
  } else if (tempPatient.patId !== onStagePatient.value.patId) {
    onStagePatient.value = tempPatient
    setOnStagePatient(tempPatient)
  }
}

const initLoad = async () => {
  if (roomBedVO.roomId == null) {
    ElNotification.error({
      message: '请重新就座!',
      type: 'info',
      duration: 3000 // 自动关闭时间，默认为3000ms
    })
    return
  }

  patientList.value = await DoctorApi.getToBeCheckedPatientList(roomBedVO)
  getOnstagePatient()
  patientStat.value = await DoctorApi.getDevReadyStatistic(roomBedVO)
  const queueVO2 = await DoctorApi.bedDoctorGet(roomBedVO)
  if (queueVO2.status === 20)  // 工位状态 有医生
    state.value = true
  else if (queueVO2.status === 30)  // 工位状态 暂停
    state.value = false
}

const bedControl = async () => {
  bedControlFlag.value = true
  try {
    if (state.value) {
      await DoctorApi.bedDoctorPause(roomBedVO)
      state.value = false
    } else {
      await DoctorApi.bedDoctorResume(roomBedVO)
      state.value = true
    }
  } finally {
    bedControlFlag.value = false
  }
}

const doctorTimer = () => {
  console.log('doctorTimer ...')
  initLoad()
  if (timerRunFlag)
    setTimeout(doctorTimer, 5000) // five seconds
}

/** 初始化 **/
onMounted(() => {
  timerRunFlag = false
  bedControlFlag.value = true
  finishFlag.value = true
  passFlag.value = true

  if (roomStore.isSetRoom) {
    roomBedVO.roomId = roomStore.room!.roomId
    roomBedVO.roomName = roomStore.room!.roomName
    roomBedVO.bedNo = roomStore.room!.bedNo
    roomBedVO.checkTypes = roomStore.room!.checkTypes
    roomBedVO.opType = roomStore.room!.opType

    timerRunFlag = true
    doctorTimer()
  } else {
    roomBedVO.roomId = null
    roomBedVO.bedNo = null
  }

  bedControlFlag.value = false
  finishFlag.value = false
  passFlag.value = false
})

onUnmounted( () =>{
  timerRunFlag = false
})

const onEventDevReady = () => {
   //console.info("onDevRentPanelEvent...")
  onStagePatient.value.patId = ""

  console.info("autoCall " + autoCall.value)
  if (autoCall.value) {
    finishNextPatient()
  } else {
    initLoad()
  }
}

const onEventRecallFinish = () => {
  initLoad()
}

/** 患者变更操作 */
const devReadyPanelRef = ref()
const setOnStagePatient = (tempPatient: QueueVO | undefined) => {
  devReadyPanelRef.value.setPatient(tempPatient)
}

</script>

<template>
  <el-container>
    <el-header style="background-color: var(--el-color-primary-light-7); font-size: 24px">
      <TitlePanel :titleType=1 :room="roomBedVO" :patientStatistic="patientStat" />
    </el-header>
    <el-container style="height: 100%;">
      <el-main style="border: solid var(--el-color-primary-light-7)">
        <DevReadyPanel :room="roomBedVO" ref="devReadyPanelRef" @event_dev_ready="onEventDevReady"/>
      </el-main>
      <el-aside width="400px" style="border: solid var(--el-color-primary-light-7)">
          <QueuePanel :room="roomBedVO" :queue="patientList" @event_RecallFinish="onEventRecallFinish"/>
      </el-aside>
    </el-container>
    <el-container class="right-bottom">
      <el-checkbox label="自动&nbsp;" v-model="autoCall" />
      <el-button :disabled="finishFlag" type="primary" @click="finishNextPatient">叫号</el-button>
      <el-button :disabled="passFlag" type="primary" @click="passNextPatient">过号</el-button>
      <el-button  type="primary" @click="callAgain">重叫</el-button>
      <el-button :disabled="bedControlFlag" type="primary" @click="bedControl">{{state?'暂停':'恢复'}}</el-button>
    </el-container>
  </el-container>
</template>

<style scoped lang="scss">
.right-bottom {
  position: absolute;
  bottom: 50px;
  right: 80px;
  //background-color: #f00;
  //color: #fff;
  //padding: 10px;
}
</style>
